AbortRegistration

Struct AbortRegistration 

pub struct AbortRegistration {
    pub(crate) inner: Arc<AbortInner>,
}
A registration handle for an Abortable task. Values of this type can be acquired from AbortHandle::new and are used in calls to Abortable::new.

Fields

inner: Arc<AbortInner>

Implementations



impl AbortRegistration

pub fn handle(&self) -> AbortHandle

Create an AbortHandle from the given AbortRegistration.

The created AbortHandle is functionally the same as any other AbortHandles that are associated with the same AbortRegistration, such as the one created by AbortHandle::new_pair.