Struct TryChunksError
pub struct TryChunksError<T, E>(pub Vec<T>, pub E);Expand description
Error indicating, that while chunk was collected inner stream produced an error.
Contains all items that were collected before an error occurred, and the stream error itself.
Tuple Fields
0: Vec<T>1: ETrait Implementations
impl<T, E> Debug for TryChunksError<T, E>where
E: Debug,
impl<T, E> Debug for TryChunksError<T, E>where
E: Debug,
impl<T, E> Display for TryChunksError<T, E>where
E: Display,
impl<T, E> Display for TryChunksError<T, E>where
E: Display,
impl<T, E> Error for TryChunksError<T, E>
Available on crate feature std only.
impl<T, E> Error for TryChunksError<T, E>
Available on crate feature
std only.1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
impl<T, E> PartialEq for TryChunksError<T, E>
impl<T, E> PartialEq for TryChunksError<T, E>
impl<T, E> Eq for TryChunksError<T, E>
impl<T, E> StructuralPartialEq for TryChunksError<T, E>